@@ -12,6 +12,6 @@ class Item(BaseModel):
     tags: set[str] = set()
 
 
-@app.post("/items/", response_model=Item, status_code=status.HTTP_201_CREATED)
-async def create_item(item: Item):
+@app.post("/items/", status_code=status.HTTP_201_CREATED)
+async def create_item(item: Item) -> Item:
     return item
