@@ -444,229 +444,235 @@ def test_openapi_schema_no_separate():
     client = get_app_client(separate_input_output_schemas=False)
     response = client.get("/openapi.json")
     assert response.status_code == 200, response.text
-    assert response.json() == {
-        "openapi": "3.1.0",
-        "info": {"title": "FastAPI", "version": "0.1.0"},
-        "paths": {
-            "/items/": {
-                "get": {
-                    "summary": "Read Items",
-                    "operationId": "read_items_items__get",
-                    "responses": {
-                        "200": {
-                            "description": "Successful Response",
+    assert response.json() == snapshot(
+        {
+            "openapi": "3.1.0",
+            "info": {"title": "FastAPI", "version": "0.1.0"},
+            "paths": {
+                "/items/": {
+                    "get": {
+                        "summary": "Read Items",
+                        "operationId": "read_items_items__get",
+                        "responses": {
+                            "200": {
+                                "description": "Successful Response",
+                                "content": {
+                                    "application/json": {
+                                        "schema": {
+                                            "items": {
+                                                "$ref": "#/components/schemas/Item"
+                                            },
+                                            "type": "array",
+                                            "title": "Response Read Items Items  Get",
+                                        }
+                                    }
+                                },
+                            }
+                        },
+                    },
+                    "post": {
+                        "summary": "Create Item",
+                        "operationId": "create_item_items__post",
+                        "requestBody": {
+                            "content": {
+                                "application/json": {
+                                    "schema": {"$ref": "#/components/schemas/Item"}
+                                }
+                            },
+                            "required": True,
+                        },
+                        "responses": {
+                            "200": {
+                                "description": "Successful Response",
+                                "content": {
+                                    "application/json": {
+                                        "schema": {"$ref": "#/components/schemas/Item"}
+                                    }
+                                },
+                            },
+                            "402": {
+                                "description": "Payment Required",
+                                "content": {
+                                    "application/json": {
+                                        "schema": {"$ref": "#/components/schemas/Item"}
+                                    }
+                                },
+                            },
+                            "422": {
+                                "description": "Validation Error",
+                                "content": {
+                                    "application/json": {
+                                        "schema": {
+                                            "$ref": "#/components/schemas/HTTPValidationError"
+                                        }
+                                    }
+                                },
+                            },
+                        },
+                    },
+                },
+                "/items-list/": {
+                    "post": {
+                        "summary": "Create Item List",
+                        "operationId": "create_item_list_items_list__post",
+                        "requestBody": {
                             "content": {
                                 "application/json": {
                                     "schema": {
                                         "items": {"$ref": "#/components/schemas/Item"},
                                         "type": "array",
-                                        "title": "Response Read Items Items  Get",
+                                        "title": "Item",
                                     }
                                 }
                             },
-                        }
-                    },
+                            "required": True,
+                        },
+                        "responses": {
+                            "200": {
+                                "description": "Successful Response",
+                                "content": {"application/json": {"schema": {}}},
+                            },
+                            "422": {
+                                "description": "Validation Error",
+                                "content": {
+                                    "application/json": {
+                                        "schema": {
+                                            "$ref": "#/components/schemas/HTTPValidationError"
+                                        }
+                                    }
+                                },
+                            },
+                        },
+                    }
                 },
-                "post": {
-                    "summary": "Create Item",
-                    "operationId": "create_item_items__post",
-                    "requestBody": {
-                        "content": {
-                            "application/json": {
-                                "schema": {"$ref": "#/components/schemas/Item"}
-                            }
-                        },
-                        "required": True,
-                    },
-                    "responses": {
-                        "200": {
-                            "description": "Successful Response",
-                            "content": {
-                                "application/json": {
-                                    "schema": {"$ref": "#/components/schemas/Item"}
-                                }
-                            },
-                        },
-                        "402": {
-                            "description": "Payment Required",
-                            "content": {
-                                "application/json": {
-                                    "schema": {"$ref": "#/components/schemas/Item"}
-                                }
-                            },
-                        },
-                        "422": {
-                            "description": "Validation Error",
+                "/with-computed-field/": {
+                    "post": {
+                        "summary": "Create With Computed Field",
+                        "operationId": "create_with_computed_field_with_computed_field__post",
+                        "requestBody": {
                             "content": {
                                 "application/json": {
                                     "schema": {
-                                        "$ref": "#/components/schemas/HTTPValidationError"
+                                        "$ref": "#/components/schemas/WithComputedField-Input"
                                     }
                                 }
                             },
+                            "required": True,
+                        },
+                        "responses": {
+                            "200": {
+                                "description": "Successful Response",
+                                "content": {
+                                    "application/json": {
+                                        "schema": {
+                                            "$ref": "#/components/schemas/WithComputedField-Output"
+                                        }
+                                    }
+                                },
+                            },
+                            "422": {
+                                "description": "Validation Error",
+                                "content": {
+                                    "application/json": {
+                                        "schema": {
+                                            "$ref": "#/components/schemas/HTTPValidationError"
+                                        }
+                                    }
+                                },
+                            },
                         },
                     },
                 },
             },
-            "/items-list/": {
-                "post": {
-                    "summary": "Create Item List",
-                    "operationId": "create_item_list_items_list__post",
-                    "requestBody": {
-                        "content": {
-                            "application/json": {
-                                "schema": {
-                                    "items": {"$ref": "#/components/schemas/Item"},
-                                    "type": "array",
-                                    "title": "Item",
-                                }
+            "components": {
+                "schemas": {
+                    "HTTPValidationError": {
+                        "properties": {
+                            "detail": {
+                                "items": {
+                                    "$ref": "#/components/schemas/ValidationError"
+                                },
+                                "type": "array",
+                                "title": "Detail",
                             }
                         },
-                        "required": True,
+                        "type": "object",
+                        "title": "HTTPValidationError",
                     },
-                    "responses": {
-                        "200": {
-                            "description": "Successful Response",
-                            "content": {"application/json": {"schema": {}}},
-                        },
-                        "422": {
-                            "description": "Validation Error",
-                            "content": {
-                                "application/json": {
-                                    "schema": {
-                                        "$ref": "#/components/schemas/HTTPValidationError"
-                                    }
-                                }
+                    "Item": {
+                        "properties": {
+                            "name": {"type": "string", "title": "Name"},
+                            "description": {
+                                "anyOf": [{"type": "string"}, {"type": "null"}],
+                                "title": "Description",
+                            },
+                            "sub": {
+                                "anyOf": [
+                                    {"$ref": "#/components/schemas/SubItem"},
+                                    {"type": "null"},
+                                ]
                             },
                         },
+                        "type": "object",
+                        "required": ["name"],
+                        "title": "Item",
+                    },
+                    "SubItem": {
+                        "properties": {
+                            "subname": {"type": "string", "title": "Subname"},
+                            "sub_description": {
+                                "anyOf": [{"type": "string"}, {"type": "null"}],
+                                "title": "Sub Description",
+                            },
+                            "tags": {
+                                "items": {"type": "string"},
+                                "type": "array",
+                                "title": "Tags",
+                                "default": [],
+                            },
+                        },
+                        "type": "object",
+                        "required": ["subname"],
+                        "title": "SubItem",
+                    },
+                    "WithComputedField-Input": {
+                        "properties": {"name": {"type": "string", "title": "Name"}},
+                        "type": "object",
+                        "required": ["name"],
+                        "title": "WithComputedField",
+                    },
+                    "WithComputedField-Output": {
+                        "properties": {
+                            "name": {"type": "string", "title": "Name"},
+                            "computed_field": {
+                                "type": "string",
+                                "title": "Computed Field",
+                                "readOnly": True,
+                            },
+                        },
+                        "type": "object",
+                        "required": ["name", "computed_field"],
+                        "title": "WithComputedField",
+                    },
+                    "ValidationError": {
+                        "properties": {
+                            "ctx": {"title": "Context", "type": "object"},
+                            "input": {"title": "Input"},
+                            "loc": {
+                                "items": {
+                                    "anyOf": [{"type": "string"}, {"type": "integer"}]
+                                },
+                                "type": "array",
+                                "title": "Location",
+                            },
+                            "msg": {"type": "string", "title": "Message"},
+                            "type": {"type": "string", "title": "Error Type"},
+                        },
+                        "type": "object",
+                        "required": ["loc", "msg", "type"],
+                        "title": "ValidationError",
                     },
                 }
             },
-            "/with-computed-field/": {
-                "post": {
-                    "summary": "Create With Computed Field",
-                    "operationId": "create_with_computed_field_with_computed_field__post",
-                    "requestBody": {
-                        "content": {
-                            "application/json": {
-                                "schema": {
-                                    "$ref": "#/components/schemas/WithComputedField-Input"
-                                }
-                            }
-                        },
-                        "required": True,
-                    },
-                    "responses": {
-                        "200": {
-                            "description": "Successful Response",
-                            "content": {
-                                "application/json": {
-                                    "schema": {
-                                        "$ref": "#/components/schemas/WithComputedField-Output"
-                                    }
-                                }
-                            },
-                        },
-                        "422": {
-                            "description": "Validation Error",
-                            "content": {
-                                "application/json": {
-                                    "schema": {
-                                        "$ref": "#/components/schemas/HTTPValidationError"
-                                    }
-                                }
-                            },
-                        },
-                    },
-                },
-            },
-        },
-        "components": {
-            "schemas": {
-                "HTTPValidationError": {
-                    "properties": {
-                        "detail": {
-                            "items": {"$ref": "#/components/schemas/ValidationError"},
-                            "type": "array",
-                            "title": "Detail",
-                        }
-                    },
-                    "type": "object",
-                    "title": "HTTPValidationError",
-                },
-                "Item": {
-                    "properties": {
-                        "name": {"type": "string", "title": "Name"},
-                        "description": {
-                            "anyOf": [{"type": "string"}, {"type": "null"}],
-                            "title": "Description",
-                        },
-                        "sub": {
-                            "anyOf": [
-                                {"$ref": "#/components/schemas/SubItem"},
-                                {"type": "null"},
-                            ]
-                        },
-                    },
-                    "type": "object",
-                    "required": ["name"],
-                    "title": "Item",
-                },
-                "SubItem": {
-                    "properties": {
-                        "subname": {"type": "string", "title": "Subname"},
-                        "sub_description": {
-                            "anyOf": [{"type": "string"}, {"type": "null"}],
-                            "title": "Sub Description",
-                        },
-                        "tags": {
-                            "items": {"type": "string"},
-                            "type": "array",
-                            "title": "Tags",
-                            "default": [],
-                        },
-                    },
-                    "type": "object",
-                    "required": ["subname"],
-                    "title": "SubItem",
-                },
-                "WithComputedField-Input": {
-                    "properties": {"name": {"type": "string", "title": "Name"}},
-                    "type": "object",
-                    "required": ["name"],
-                    "title": "WithComputedField",
-                },
-                "WithComputedField-Output": {
-                    "properties": {
-                        "name": {"type": "string", "title": "Name"},
-                        "computed_field": {
-                            "type": "string",
-                            "title": "Computed Field",
-                            "readOnly": True,
-                        },
-                    },
-                    "type": "object",
-                    "required": ["name", "computed_field"],
-                    "title": "WithComputedField",
-                },
-                "ValidationError": {
-                    "properties": {
-                        "ctx": {"title": "Context", "type": "object"},
-                        "input": {"title": "Input"},
-                        "loc": {
-                            "items": {
-                                "anyOf": [{"type": "string"}, {"type": "integer"}]
-                            },
-                            "type": "array",
-                            "title": "Location",
-                        },
-                        "msg": {"type": "string", "title": "Message"},
-                        "type": {"type": "string", "title": "Error Type"},
-                    },
-                    "type": "object",
-                    "required": ["loc", "msg", "type"],
-                    "title": "ValidationError",
-                },
-            }
-        },
-    }
+        }
+    )
