@@ -1,13 +1,10 @@
 from typing import Annotated, Optional
 
 import pytest
-from dirty_equals import IsDict
 from fastapi import Body, FastAPI
 from fastapi.testclient import TestClient
 from pydantic import BaseModel, Field
 
-from tests.utils import needs_pydanticv2
-
 from .utils import get_body_model_name
 
 app = FastAPI()
@@ -40,30 +37,19 @@ def test_optional_list_str_schema(path: str):
     openapi = app.openapi()
     body_model_name = get_body_model_name(openapi, path)
 
-    assert app.openapi()["components"]["schemas"][body_model_name] == IsDict(
-        {
-            "properties": {
-                "p": {
-                    "anyOf": [
-                        {"items": {"type": "string"}, "type": "array"},
-                        {"type": "null"},
-                    ],
-                    "title": "P",
-                },
+    assert app.openapi()["components"]["schemas"][body_model_name] == {
+        "properties": {
+            "p": {
+                "anyOf": [
+                    {"items": {"type": "string"}, "type": "array"},
+                    {"type": "null"},
+                ],
+                "title": "P",
             },
-            "title": body_model_name,
-            "type": "object",
-        }
-    ) | IsDict(
-        # TODO: remove when deprecating Pydantic v1
-        {
-            "properties": {
-                "p": {"items": {"type": "string"}, "type": "array", "title": "P"},
-            },
-            "title": body_model_name,
-            "type": "object",
-        }
-    )
+        },
+        "title": body_model_name,
+        "type": "object",
+    }
 
 
 def test_optional_list_str_missing():
@@ -77,29 +63,16 @@ def test_model_optional_list_str_missing():
     client = TestClient(app)
     response = client.post("/model-optional-list-str")
     assert response.status_code == 422, response.text
-    assert response.json() == IsDict(
-        {
-            "detail": [
-                {
-                    "input": None,
-                    "loc": ["body"],
-                    "msg": "Field required",
-                    "type": "missing",
-                },
-            ],
-        }
-    ) | IsDict(
-        {
-            # TODO: remove when deprecating Pydantic v1
-            "detail": [
-                {
-                    "loc": ["body"],
-                    "msg": "field required",
-                    "type": "value_error.missing",
-                },
-            ],
-        }
-    )
+    assert response.json() == {
+        "detail": [
+            {
+                "input": None,
+                "loc": ["body"],
+                "msg": "Field required",
+                "type": "missing",
+            },
+        ],
+    }
 
 
 @pytest.mark.parametrize(
@@ -155,34 +128,19 @@ def test_optional_list_str_alias_schema(path: str):
     openapi = app.openapi()
     body_model_name = get_body_model_name(openapi, path)
 
-    assert app.openapi()["components"]["schemas"][body_model_name] == IsDict(
-        {
-            "properties": {
-                "p_alias": {
-                    "anyOf": [
-                        {"items": {"type": "string"}, "type": "array"},
-                        {"type": "null"},
-                    ],
-                    "title": "P Alias",
-                },
+    assert app.openapi()["components"]["schemas"][body_model_name] == {
+        "properties": {
+            "p_alias": {
+                "anyOf": [
+                    {"items": {"type": "string"}, "type": "array"},
+                    {"type": "null"},
+                ],
+                "title": "P Alias",
             },
-            "title": body_model_name,
-            "type": "object",
-        }
-    ) | IsDict(
-        # TODO: remove when deprecating Pydantic v1
-        {
-            "properties": {
-                "p_alias": {
-                    "items": {"type": "string"},
-                    "type": "array",
-                    "title": "P Alias",
-                },
-            },
-            "title": body_model_name,
-            "type": "object",
-        }
-    )
+        },
+        "title": body_model_name,
+        "type": "object",
+    }
 
 
 def test_optional_list_alias_missing():
@@ -196,29 +154,16 @@ def test_model_optional_list_alias_missing():
     client = TestClient(app)
     response = client.post("/model-optional-list-alias")
     assert response.status_code == 422, response.text
-    assert response.json() == IsDict(
-        {
-            "detail": [
-                {
-                    "input": None,
-                    "loc": ["body"],
-                    "msg": "Field required",
-                    "type": "missing",
-                },
-            ],
-        }
-    ) | IsDict(
-        {
-            # TODO: remove when deprecating Pydantic v1
-            "detail": [
-                {
-                    "loc": ["body"],
-                    "msg": "field required",
-                    "type": "value_error.missing",
-                },
-            ],
-        }
-    )
+    assert response.json() == {
+        "detail": [
+            {
+                "input": None,
+                "loc": ["body"],
+                "msg": "Field required",
+                "type": "missing",
+            },
+        ],
+    }
 
 
 @pytest.mark.parametrize(
@@ -283,7 +228,6 @@ def read_model_optional_list_validation_alias(
     return {"p": p.p}
 
 
-@needs_pydanticv2
 @pytest.mark.parametrize(
     "path",
     ["/optional-list-validation-alias", "/model-optional-list-validation-alias"],
@@ -292,34 +236,19 @@ def test_optional_list_validation_alias_schema(path: str):
     openapi = app.openapi()
     body_model_name = get_body_model_name(openapi, path)
 
-    assert app.openapi()["components"]["schemas"][body_model_name] == IsDict(
-        {
-            "properties": {
-                "p_val_alias": {
-                    "anyOf": [
-                        {"items": {"type": "string"}, "type": "array"},
-                        {"type": "null"},
-                    ],
-                    "title": "P Val Alias",
-                },
+    assert app.openapi()["components"]["schemas"][body_model_name] == {
+        "properties": {
+            "p_val_alias": {
+                "anyOf": [
+                    {"items": {"type": "string"}, "type": "array"},
+                    {"type": "null"},
+                ],
+                "title": "P Val Alias",
             },
-            "title": body_model_name,
-            "type": "object",
-        }
-    ) | IsDict(
-        # TODO: remove when deprecating Pydantic v1
-        {
-            "properties": {
-                "p_val_alias": {
-                    "items": {"type": "string"},
-                    "type": "array",
-                    "title": "P Val Alias",
-                },
-            },
-            "title": body_model_name,
-            "type": "object",
-        }
-    )
+        },
+        "title": body_model_name,
+        "type": "object",
+    }
 
 
 def test_optional_list_validation_alias_missing():
@@ -333,29 +262,16 @@ def test_model_optional_list_validation_alias_missing():
     client = TestClient(app)
     response = client.post("/model-optional-list-validation-alias")
     assert response.status_code == 422, response.text
-    assert response.json() == IsDict(
-        {
-            "detail": [
-                {
-                    "input": None,
-                    "loc": ["body"],
-                    "msg": "Field required",
-                    "type": "missing",
-                },
-            ],
-        }
-    ) | IsDict(
-        {
-            # TODO: remove when deprecating Pydantic v1
-            "detail": [
-                {
-                    "loc": ["body"],
-                    "msg": "field required",
-                    "type": "value_error.missing",
-                },
-            ],
-        }
-    )
+    assert response.json() == {
+        "detail": [
+            {
+                "input": None,
+                "loc": ["body"],
+                "msg": "Field required",
+                "type": "missing",
+            },
+        ],
+    }
 
 
 @pytest.mark.parametrize(
@@ -369,7 +285,6 @@ def test_optional_list_validation_alias_missing_empty_dict(path: str):
     assert response.json() == {"p": None}
 
 
-@needs_pydanticv2
 @pytest.mark.parametrize(
     "path",
     [
@@ -384,7 +299,6 @@ def test_optional_list_validation_alias_by_name(path: str):
     assert response.json() == {"p": None}
 
 
-@needs_pydanticv2
 @pytest.mark.parametrize(
     "path",
     [
@@ -432,7 +346,6 @@ def read_model_optional_list_alias_and_validation_alias(
     return {"p": p.p}
 
 
-@needs_pydanticv2
 @pytest.mark.parametrize(
     "path",
     [
@@ -444,34 +357,19 @@ def test_optional_list_alias_and_validation_alias_schema(path: str):
     openapi = app.openapi()
     body_model_name = get_body_model_name(openapi, path)
 
-    assert app.openapi()["components"]["schemas"][body_model_name] == IsDict(
-        {
-            "properties": {
-                "p_val_alias": {
-                    "anyOf": [
-                        {"items": {"type": "string"}, "type": "array"},
-                        {"type": "null"},
-                    ],
-                    "title": "P Val Alias",
-                },
+    assert app.openapi()["components"]["schemas"][body_model_name] == {
+        "properties": {
+            "p_val_alias": {
+                "anyOf": [
+                    {"items": {"type": "string"}, "type": "array"},
+                    {"type": "null"},
+                ],
+                "title": "P Val Alias",
             },
-            "title": body_model_name,
-            "type": "object",
-        }
-    ) | IsDict(
-        # TODO: remove when deprecating Pydantic v1
-        {
-            "properties": {
-                "p_val_alias": {
-                    "items": {"type": "string"},
-                    "type": "array",
-                    "title": "P Val Alias",
-                },
-            },
-            "title": body_model_name,
-            "type": "object",
-        }
-    )
+        },
+        "title": body_model_name,
+        "type": "object",
+    }
 
 
 def test_optional_list_alias_and_validation_alias_missing():
@@ -485,29 +383,16 @@ def test_model_optional_list_alias_and_validation_alias_missing():
     client = TestClient(app)
     response = client.post("/model-optional-list-alias-and-validation-alias")
     assert response.status_code == 422, response.text
-    assert response.json() == IsDict(
-        {
-            "detail": [
-                {
-                    "input": None,
-                    "loc": ["body"],
-                    "msg": "Field required",
-                    "type": "missing",
-                },
-            ],
-        }
-    ) | IsDict(
-        {
-            # TODO: remove when deprecating Pydantic v1
-            "detail": [
-                {
-                    "loc": ["body"],
-                    "msg": "field required",
-                    "type": "value_error.missing",
-                },
-            ],
-        }
-    )
+    assert response.json() == {
+        "detail": [
+            {
+                "input": None,
+                "loc": ["body"],
+                "msg": "Field required",
+                "type": "missing",
+            },
+        ],
+    }
 
 
 @pytest.mark.parametrize(
@@ -524,7 +409,6 @@ def test_optional_list_alias_and_validation_alias_missing_empty_dict(path: str):
     assert response.json() == {"p": None}
 
 
-@needs_pydanticv2
 @pytest.mark.parametrize(
     "path",
     [
@@ -539,7 +423,6 @@ def test_optional_list_alias_and_validation_alias_by_name(path: str):
     assert response.json() == {"p": None}
 
 
-@needs_pydanticv2
 @pytest.mark.parametrize(
     "path",
     [
@@ -554,7 +437,6 @@ def test_optional_list_alias_and_validation_alias_by_alias(path: str):
     assert response.json() == {"p": None}
 
 
-@needs_pydanticv2
 @pytest.mark.parametrize(
     "path",
     [
