@@ -3,6 +3,7 @@ from typing import Optional
 from fastapi import FastAPI, Security
 from fastapi.security import OAuth2AuthorizationCodeBearer
 from fastapi.testclient import TestClient
+from inline_snapshot import snapshot
 
 app = FastAPI()
 
@@ -46,36 +47,38 @@ def test_token_with_whitespaces():
 def test_openapi_schema():
     response = client.get("/openapi.json")
     assert response.status_code == 200, response.text
-    assert response.json() == {
-        "openapi": "3.1.0",
-        "info": {"title": "FastAPI", "version": "0.1.0"},
-        "paths": {
-            "/items/": {
-                "get": {
-                    "responses": {
-                        "200": {
-                            "description": "Successful Response",
-                            "content": {"application/json": {"schema": {}}},
-                        }
-                    },
-                    "summary": "Read Items",
-                    "operationId": "read_items_items__get",
-                    "security": [{"OAuth2AuthorizationCodeBearer": []}],
+    assert response.json() == snapshot(
+        {
+            "openapi": "3.1.0",
+            "info": {"title": "FastAPI", "version": "0.1.0"},
+            "paths": {
+                "/items/": {
+                    "get": {
+                        "responses": {
+                            "200": {
+                                "description": "Successful Response",
+                                "content": {"application/json": {"schema": {}}},
+                            }
+                        },
+                        "summary": "Read Items",
+                        "operationId": "read_items_items__get",
+                        "security": [{"OAuth2AuthorizationCodeBearer": []}],
+                    }
                 }
-            }
-        },
-        "components": {
-            "securitySchemes": {
-                "OAuth2AuthorizationCodeBearer": {
-                    "type": "oauth2",
-                    "flows": {
-                        "authorizationCode": {
-                            "authorizationUrl": "authorize",
-                            "tokenUrl": "token",
-                            "scopes": {},
-                        }
-                    },
+            },
+            "components": {
+                "securitySchemes": {
+                    "OAuth2AuthorizationCodeBearer": {
+                        "type": "oauth2",
+                        "flows": {
+                            "authorizationCode": {
+                                "authorizationUrl": "authorize",
+                                "tokenUrl": "token",
+                                "scopes": {},
+                            }
+                        },
+                    }
                 }
-            }
-        },
-    }
+            },
+        }
+    )
