@@ -5,8 +5,6 @@ import pytest
 from fastapi.testclient import TestClient
 from pytest import MonkeyPatch
 
-from ...utils import needs_pydanticv1
-
 
 @pytest.fixture(
     name="mod_path",
@@ -34,16 +32,6 @@ def test_settings(main_mod: ModuleType, monkeypatch: MonkeyPatch):
     assert settings.items_per_user == 50
 
 
-@needs_pydanticv1
-def test_settings_pv1(mod_path: str, monkeypatch: MonkeyPatch):
-    monkeypatch.setenv("ADMIN_EMAIL", "admin@example.com")
-    config_mod = importlib.import_module(f"{mod_path}.config_pv1")
-    settings = config_mod.Settings()
-    assert settings.app_name == "Awesome API"
-    assert settings.admin_email == "admin@example.com"
-    assert settings.items_per_user == 50
-
-
 def test_endpoint(main_mod: ModuleType, monkeypatch: MonkeyPatch):
     monkeypatch.setenv("ADMIN_EMAIL", "admin@example.com")
     client = TestClient(main_mod.app)
